@@ -7,22 +7,23 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
-from datetime import timedelta as td
 from functools import lru_cache
 from typing import Optional
 
+from holidays.calendars.gregorian import _timedelta
+
 KHMER_CALENDAR = "KHMER_CALENDAR"
 THAI_CALENDAR = "THAI_CALENDAR"
 
 
 class _ThaiLunisolar:
     """
-    ** Thai Lunar Calendar Holidays only work from 1941 (B.E. 2484) onwards
-       until 2057 (B.E. 2600) as we only have Thai year-type data for
+    ** Thai Lunar Calendar Holidays only work from 1913 (B.E. 2456/2455) onwards
+       until 2157 (B.E. 2700) as we only have Thai year-type data for
        cross-checking until then.
 
     So here are the basics of the Thai Lunar Calendar
@@ -93,15 +94,21 @@ class _ThaiLunisolar:
 
     Usage example:
 
-    >>> from holidays.utils import _ThaiLunisolar
+    >>> from holidays.calendars.thai import _ThaiLunisolar
     >>> thls = _ThaiLunisolar()
     >>> print(thls.visakha_bucha_date(2010))
     2010-05-28
     """
 
-    # Athikawan (Extra-Day Year) list goes from 1941-2057 C.E.
-    # Copied off from 1757-2057 (B.E. 2300-2600) Thai Lunar Calendar
+    # Athikawan (Extra-Day Year) list goes from 1914-2157 C.E.
+    # Copied off from 1757-2157 (B.E. 2300-2700) Thai Lunar Calendar
     ATHIKAWAN_YEARS_GREGORIAN = {
+        1914,
+        1917,
+        1925,
+        1929,
+        1933,
+        1936,
         1945,
         1949,
         1952,
@@ -124,12 +131,42 @@ class _ThaiLunisolar:
         2043,
         2046,
         2052,
+        2055,
+        2058,
+        2067,
+        2071,
+        2076,
+        2083,
+        2086,
+        2092,
+        2097,
+        2103,
+        2109,
+        2111,
+        2117,
+        2121,
+        2126,
+        2133,
+        2136,
+        2142,
+        2147,
+        2153,
     }
 
-    # Athikamat (Extra-Month Year) list goes from 1941-2057 C.E.:
-    # Copied off from 1757-2057 (B.E. 2300-2600) Thai Lunar Calendar
+    # Athikamat (Extra-Month Year) list goes from 1914-2157 C.E.:
+    # Copied off from 1757-2157 (B.E. 2300-2700) Thai Lunar Calendar
     # Approx formula as follows: (common_era-78)-0.45222)%2.7118886 < 1
     ATHIKAMAT_YEARS_GREGORIAN = {
+        1915,
+        1918,
+        1920,
+        1923,
+        1926,
+        1928,
+        1931,
+        1934,
+        1937,
+        1939,
         1942,
         1944,
         1947,
@@ -173,16 +210,53 @@ class _ThaiLunisolar:
         2050,
         2053,
         2056,
+        2059,
+        2062,
+        2064,
+        2066,
+        2069,
+        2072,
+        2074,
+        2077,
+        2080,
+        2082,
+        2085,
+        2088,
+        2091,
+        2094,
+        2096,
+        2099,
+        2101,
+        2104,
+        2107,
+        2112,
+        2114,
+        2116,
+        2119,
+        2122,
+        2124,
+        2127,
+        2130,
+        2132,
+        2135,
+        2138,
+        2141,
+        2144,
+        2146,
+        2149,
+        2151,
+        2154,
+        2157,
     }
 
     # While Buddhist Holy Days have been observed since the 1900s
-    #   Due to the calendar changes in 1941 (B.E. 2484) and that
-    #   our array only goes up to B.E. 2600; We'll thus only populate
-    #   the data for 1941-2057 (B.E. 2484-2600).
+    #   Thailand's Public Holiday Act wasn't codified until 1914 (B.E. 2457)
+    #   and that our array only goes up to B.E. 2700; We'll thus only populate
+    #   the data for 1914-2157 (B.E. 2457-2700).
     # Sources: หนังสือเวียนกรมการปกครอง กระทรวงมหาดไทย มท 0310.1/ว4 5 ก.พ. 2539
-    START_DATE = date(1940, 11, 30)
-    START_YEAR = 1941
-    END_YEAR = 2057
+    START_DATE = date(1913, 11, 28)
+    START_YEAR = 1914
+    END_YEAR = 2157
 
     def __init__(self, calendar=THAI_CALENDAR) -> None:
         self.__verify_calendar(calendar)
@@ -206,13 +280,13 @@ class _ThaiLunisolar:
                 f"Unknown calendar name: {calendar}. Use `KHMER_CALENDAR` or `THAI_CALENDAR`."
             )
 
-    @lru_cache()
+    @lru_cache
     def _get_start_date(self, year: int) -> Optional[date]:
         """
         Calculate the start date of that particular Thai Lunar Calendar Year.
         This usually falls in November or December of the previous Gregorian
         year in question. Should the year be outside of working scope
-        (1941-2057: B.E 2484-2600), this will returns None instead.
+        (1914-2157: B.E 2457-2700), this will returns None instead.
 
         :param year:
             The Gregorian year.
@@ -230,7 +304,7 @@ class _ThaiLunisolar:
             elif iter_year in _ThaiLunisolar.ATHIKAWAN_YEARS_GREGORIAN:
                 delta_days += 1
 
-        return _ThaiLunisolar.START_DATE + td(days=delta_days)
+        return _timedelta(_ThaiLunisolar.START_DATE, delta_days)
 
     def makha_bucha_date(self, year: int, calendar=None) -> Optional[date]:
         """
@@ -267,13 +341,14 @@ class _ThaiLunisolar:
         if not start_date:
             return None
 
-        return start_date + td(
-            days=+102
+        return _timedelta(
+            start_date,
+            +102
             if (
                 year in _ThaiLunisolar.ATHIKAMAT_YEARS_GREGORIAN
                 and not self.__is_khmer_calendar(calendar)
             )
-            else +73
+            else +73,
         )
 
     def visakha_bucha_date(self, year: int, calendar=None) -> Optional[date]:
@@ -310,13 +385,14 @@ class _ThaiLunisolar:
         if not start_date:
             return None
 
-        return start_date + td(
-            days=+191
+        return _timedelta(
+            start_date,
+            +191
             if (
                 year in _ThaiLunisolar.ATHIKAMAT_YEARS_GREGORIAN
                 and not self.__is_khmer_calendar(calendar)
             )
-            else +161
+            else +161,
         )
 
     def preah_neangkoal_date(self, year: int) -> Optional[date]:
@@ -346,7 +422,7 @@ class _ThaiLunisolar:
         if not start_date:
             return None
 
-        return start_date + td(days=+165)
+        return _timedelta(start_date, +165)
 
     def atthami_bucha_date(self, year: int, calendar=None) -> Optional[date]:
         """
@@ -383,13 +459,14 @@ class _ThaiLunisolar:
         if not start_date:
             return None
 
-        return start_date + td(
-            days=+199
+        return _timedelta(
+            start_date,
+            +199
             if (
                 year in _ThaiLunisolar.ATHIKAMAT_YEARS_GREGORIAN
                 and not self.__is_khmer_calendar(calendar)
             )
-            else +169
+            else +169,
         )
 
     def asarnha_bucha_date(self, year: int) -> Optional[date]:
@@ -414,9 +491,6 @@ class _ThaiLunisolar:
         :param year:
             The Gregorian year.
 
-        :param calendar:
-            Calendar type, this defaults to THAI_CALENDAR.
-
         :return:
             Estimated Gregorian date of Asarnha Bucha.
         """
@@ -430,7 +504,7 @@ class _ThaiLunisolar:
             delta_days = +221
         else:
             delta_days = +220
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def khao_phansa_date(self, year: int) -> Optional[date]:
         """
@@ -453,9 +527,6 @@ class _ThaiLunisolar:
         :param year:
             The Gregorian year.
 
-        :param calendar:
-            Calendar type, this defaults to THAI_CALENDAR.
-
         :return:
             Estimated Gregorian date of Khao Phansa.
         """
@@ -469,7 +540,7 @@ class _ThaiLunisolar:
             delta_days = +222
         else:
             delta_days = +221
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def boun_haw_khao_padapdin_date(self, year: int) -> Optional[date]:
         """
@@ -503,7 +574,7 @@ class _ThaiLunisolar:
             delta_days = +265
         else:
             delta_days = +264
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def boun_haw_khao_salark_date(self, year: int) -> Optional[date]:
         """
@@ -537,7 +608,7 @@ class _ThaiLunisolar:
             delta_days = +280
         else:
             delta_days = +279
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def pchum_ben_date(self, year: int) -> Optional[date]:
         """
@@ -571,7 +642,7 @@ class _ThaiLunisolar:
             delta_days = +295
         else:
             delta_days = +294
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def ok_phansa_date(self, year: int) -> Optional[date]:
         """
@@ -605,7 +676,7 @@ class _ThaiLunisolar:
             delta_days = +310
         else:
             delta_days = +309
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def boun_suang_heua_date(self, year: int) -> Optional[date]:
         """
@@ -639,7 +710,7 @@ class _ThaiLunisolar:
             delta_days = +311
         else:
             delta_days = +310
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
 
     def loy_krathong_date(self, year: int) -> Optional[date]:
         """
@@ -673,4 +744,4 @@ class _ThaiLunisolar:
             delta_days = +339
         else:
             delta_days = +338
-        return start_date + td(days=delta_days)
+        return _timedelta(start_date, delta_days)
