@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 # flake8: noqa: F401
@@ -48,8 +48,13 @@ SCHOOL = "school"
 UNOFFICIAL = "unofficial"
 WORKDAY = "workday"
 
+CATHOLIC = "catholic"
 CHINESE = "chinese"
 CHRISTIAN = "christian"
 HEBREW = "hebrew"
 HINDU = "hindu"
 ISLAMIC = "islamic"
+ORTHODOX = "orthodox"
+
+DEFAULT_START_YEAR = 1901
+DEFAULT_END_YEAR = 2100
