@@ -7,11 +7,12 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 # flake8: noqa: F401
 
+from .afghanistan import Afghanistan, AF, AFG
 from .albania import Albania, AL, ALB
 from .algeria import Algeria, DZ, DZA
 from .american_samoa import AmericanSamoa, AS, ASM, HolidaysAS
@@ -45,6 +46,7 @@ from .chad import Chad, TD, TCD
 from .chile import Chile, CL, CHL
 from .china import China, CN, CHN
 from .colombia import Colombia, CO, COL
+from .congo import Congo, CG, COG
 from .costa_rica import CostaRica, CR, CRI
 from .croatia import Croatia, HR, HRV
 from .cuba import Cuba, CU, CUB
@@ -53,6 +55,7 @@ from .cyprus import Cyprus, CY, CYP
 from .czechia import Czechia, CZ, CZE
 from .denmark import Denmark, DK, DNK
 from .djibouti import Djibouti, DJ, DJI
+from .dominica import Dominica, DM, DMA
 from .dominican_republic import DominicanRepublic, DO, DOM
 from .ecuador import Ecuador, EC, ECU
 from .egypt import Egypt, EG, EGY
@@ -67,8 +70,11 @@ from .georgia import Georgia, GE, GEO
 from .germany import Germany, DE, DEU
 from .ghana import Ghana, GH, GHA
 from .greece import Greece, GR, GRC
+from .greenland import Greenland, GL, GRL
 from .guam import Guam, GU, GUM, HolidaysGU
 from .guatemala import Guatemala, GT, GUA
+from .guernsey import Guernsey, GG, GGY
+from .haiti import Haiti, HT, HTI
 from .honduras import Honduras, HN, HND
 from .hongkong import HongKong, HK, HKG
 from .hungary import Hungary, HU, HUN
@@ -83,6 +89,7 @@ from .italy import Italy, IT, ITA
 from .jamaica import Jamaica, JM, JAM
 from .japan import Japan, JP, JPN
 from .jersey import Jersey, JE, JEY
+from .jordan import Jordan, JO, JOR
 from .kazakhstan import Kazakhstan, KZ, KAZ
 from .kenya import Kenya, KE, KEN
 from .kuwait import Kuwait, KW, KWT
@@ -99,6 +106,7 @@ from .malaysia import Malaysia, MY, MYS
 from .maldives import Maldives, MV, MDV
 from .malta import Malta, MT, MLT
 from .marshall_islands import MarshallIslands, MH, MHL, HolidaysMH
+from .mauritania import Mauritania, MR, MRT
 from .mexico import Mexico, MX, MEX
 from .moldova import Moldova, MD, MDA
 from .monaco import Monaco, MC, MCO
@@ -114,6 +122,7 @@ from .north_macedonia import NorthMacedonia, MK, MKD
 from .northern_mariana_islands import NorthernMarianaIslands, MP, MNP, HolidaysMP
 from .norway import Norway, NO, NOR
 from .pakistan import Pakistan, PK, PAK
+from .palau import Palau, PW, PLW
 from .panama import Panama, PA, PAN
 from .papua_new_guinea import PapuaNewGuinea, PG, PNG
 from .paraguay import Paraguay, PY, PRY
@@ -124,6 +133,9 @@ from .portugal import Portugal, PT, PRT
 from .puerto_rico import PuertoRico, PR, PRI, HolidaysPR
 from .romania import Romania, RO, ROU
 from .russia import Russia, RU, RUS
+from .saint_kitts_and_nevis import SaintKittsAndNevis, KN, KNA
+from .saint_lucia import SaintLucia, LC, LCA
+from .samoa import Samoa, WS, WSM
 from .san_marino import SanMarino, SM, SMR
 from .saudi_arabia import SaudiArabia, SA, SAU
 from .serbia import Serbia, RS, SRB
@@ -134,6 +146,7 @@ from .slovenia import Slovenia, SI, SVN
 from .south_africa import SouthAfrica, ZA, ZAF
 from .south_korea import SouthKorea, KR, KOR, Korea
 from .spain import Spain, ES, ESP
+from .sri_lanka import SriLanka, LK, LKA
 from .sweden import Sweden, SE, SWE
 from .switzerland import Switzerland, CH, CHE
 from .taiwan import Taiwan, TW, TWN
@@ -143,6 +156,7 @@ from .timor_leste import TimorLeste, TL, TLS
 from .tonga import Tonga, TO, TON
 from .tunisia import Tunisia, TN, TUN
 from .turkey import Turkey, TR, TUR
+from .tuvalu import Tuvalu, TV, TUV
 from .ukraine import Ukraine, UA, UKR
 from .united_arab_emirates import UnitedArabEmirates, AE, ARE
 from .united_kingdom import UnitedKingdom, GB, GBR, UK
