@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
@@ -24,6 +24,8 @@ class Djibouti(HolidayBase, ChristianHolidays, IslamicHolidays, InternationalHol
     estimated_label = tr("%s (estimé)")
     supported_languages = ("ar", "en_US", "fr")
     weekend = {FRI, SAT}
+    # On 27 June 1977, Djibouti gained independence from France.
+    start_year = 1978
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -32,10 +34,6 @@ class Djibouti(HolidayBase, ChristianHolidays, IslamicHolidays, InternationalHol
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        # On 27 June 1977, Djibouti gained independence from France.
-        if self._year <= 1977:
-            return None
-
         # New Year's Day.
         self._add_new_years_day(tr("Nouvel an"))
 
@@ -51,7 +49,7 @@ class Djibouti(HolidayBase, ChristianHolidays, IslamicHolidays, InternationalHol
         # Christmas Day.
         self._add_christmas_day(tr("Noël"))
 
-        # Isra and Miraj.
+        # Isra' and Mi'raj.
         self._add_isra_and_miraj_day(tr("Al Isra et Al Mirague"))
 
         # Eid al-Fitr.
