@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from holidays.calendars import _CustomIslamicHolidays
@@ -26,6 +26,8 @@ class Gabon(HolidayBase, ChristianHolidays, InternationalHolidays, IslamicHolida
     """
 
     country = "GA"
+    # On 17 August 1960, Gabon gained independence from France.
+    start_year = 1961
 
     def __init__(self, *args, **kwargs) -> None:
         ChristianHolidays.__init__(self)
@@ -34,10 +36,6 @@ class Gabon(HolidayBase, ChristianHolidays, InternationalHolidays, IslamicHolida
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        # On 17 August 1960, Gabon gained independence from France.
-        if self._year <= 1960:
-            return None
-
         # New Year's Day.
         self._add_new_years_day("New Year's Day")
 
@@ -136,4 +134,5 @@ class GabonIslamicHolidays(_CustomIslamicHolidays):
         2021: (MAY, 13),
         2022: (MAY, 2),
         2023: (APR, 21),
+        2024: (APR, 10),
     }
