@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
@@ -42,7 +42,7 @@ class Luxembourg(HolidayBase, ChristianHolidays, InternationalHolidays):
 
         if self._year >= 2019:
             # Europe Day.
-            self._add_holiday_may_9(tr("Europadag"))
+            self._add_europe_day(tr("Europadag"))
 
         # Ascension Day.
         self._add_ascension_thursday(tr("Christi Himmelfaart"))
@@ -62,7 +62,7 @@ class Luxembourg(HolidayBase, ChristianHolidays, InternationalHolidays):
         # Christmas Day.
         self._add_christmas_day(tr("Chrëschtdag"))
 
-        # St. Stephen's Day.
+        # Saint Stephen's Day.
         self._add_christmas_day_two(tr("Stiefesdag"))
 
 
