@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
@@ -20,15 +20,18 @@ from holidays.holiday_base import HolidayBase
 
 class Slovakia(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
     """
-    https://en.wikipedia.org/wiki/Public_holidays_in_Slovakia
-    https://sk.wikipedia.org/wiki/Zoznam_sviatkov_na_Slovensku
-    https://www.slov-lex.sk/pravne-predpisy/SK/ZZ/1993/241/
+    References:
+        - https://en.wikipedia.org/wiki/Public_holidays_in_Slovakia
+        - https://sk.wikipedia.org/wiki/Zoznam_sviatkov_na_Slovensku
+        - https://www.slov-lex.sk/pravne-predpisy/SK/ZZ/1993/241/
     """
 
     country = "SK"
     default_language = "sk"
     supported_categories = (PUBLIC, WORKDAY)
     supported_languages = ("en_US", "sk", "uk")
+    # Independent Slovak Republic established on Jan 01, 1993.
+    start_year = 1993
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -37,10 +40,6 @@ class Slovakia(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHoli
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        # Independent Slovak Republic established on Jan 01, 1993
-        if self._year <= 1992:
-            return None
-
         # Day of the Establishment of the Slovak Republic.
         self._add_holiday_jan_1(tr("Deň vzniku Slovenskej republiky"))
 
@@ -60,16 +59,17 @@ class Slovakia(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHoli
 
         if self._year >= 1997:
             # Day of Victory over Fascism.
-            self._add_holiday_may_8(tr("Deň víťazstva nad fašizmom"))
+            self._add_world_war_two_victory_day(tr("Deň víťazstva nad fašizmom"))
 
-        # St. Cyril and Methodius Day.
+        # Saints Cyril and Methodius Day.
         self._add_holiday_jul_5(tr("Sviatok svätého Cyrila a svätého Metoda"))
 
         # Slovak National Uprising Anniversary.
         self._add_holiday_aug_29(tr("Výročie Slovenského národného povstania"))
 
-        # Constitution Day.
-        self._add_holiday_sep_1(tr("Deň Ústavy Slovenskej republiky"))
+        if self._year <= 2023:
+            # Constitution Day.
+            self._add_holiday_sep_1(tr("Deň Ústavy Slovenskej republiky"))
 
         # Day of Our Lady of the Seven Sorrows.
         self._add_holiday_sep_15(tr("Sedembolestná Panna Mária"))
@@ -91,7 +91,12 @@ class Slovakia(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHoli
         self._add_christmas_day_two(tr("Druhý sviatok vianočný"))
 
     def _populate_workday_holidays(self):
-        # According to Law 241/1993, this state holiday is not a non-working day.
+        # According to Law 241/1993, these state holidays are not non-working days.
+
+        if self._year >= 2024:
+            # Constitution Day.
+            self._add_holiday_sep_1(tr("Deň Ústavy Slovenskej republiky"))
+
         if self._year >= 2021:
             # Day of the Establishment of the Independent Czech-Slovak State.
             self._add_holiday_oct_28(tr("Deň vzniku samostatného česko-slovenského štátu"))
