@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from holidays.calendars.gregorian import JAN, MAR, APR, MAY, JUN, AUG, NOV, DEC
@@ -20,10 +20,13 @@ class SouthAfrica(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
     https://www.gov.za/about-sa/public-holidays
     https://en.wikipedia.org/wiki/Public_holidays_in_South_Africa
     https://www.gov.za/speeches/president-cyril-ramaphosa-progress-economic-recovery-30-oct-2023-0000
+    https://www.gov.za/documents/notices/public-holidays-act-declaration-29-may-2024-public-holiday-23-feb-2024
     """
 
     country = "ZA"
     observed_label = "%s (observed)"
+    # Observed since 1910, with a few name changes
+    start_year = 1910
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -34,10 +37,6 @@ class SouthAfrica(ObservedHolidayBase, ChristianHolidays, InternationalHolidays,
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        # Observed since 1910, with a few name changes
-        if self._year <= 1909:
-            return None
-
         self._add_observed(self._add_new_years_day("New Year's Day"))
 
         self._add_good_friday("Good Friday")
@@ -147,6 +146,7 @@ class SouthAfricaStaticHolidays:
         2022: (DEC, 27, presidential_decree_holiday),
         # Winning the 2023 Rugby World Cup
         2023: (DEC, 15, presidential_decree_holiday),
+        2024: (MAY, 29, national_and_provincial_elections),
     }
 
     special_public_holidays_observed = {
