@@ -7,14 +7,30 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from datetime import date
 from gettext import gettext as tr
-from typing import Set
 
-from holidays.calendars.gregorian import JAN, FEB, MAR, APR, MAY, JUN, SEP, OCT, DEC
+from holidays.calendars.gregorian import (
+    JAN,
+    FEB,
+    MAR,
+    APR,
+    MAY,
+    JUN,
+    SEP,
+    OCT,
+    DEC,
+    MON,
+    TUE,
+    WED,
+    THU,
+    FRI,
+    SAT,
+    SUN,
+)
 from holidays.groups import ChineseCalendarHolidays, InternationalHolidays, StaticHolidays
 from holidays.observed_holiday_base import (
     ObservedHolidayBase,
@@ -24,12 +40,14 @@ from holidays.observed_holiday_base import (
     SAT_SUN_TO_NEXT_WORKDAY,
 )
 
+CHILDRENS_DAY_RULE = ObservedRule({MON: +1, TUE: -1, WED: -1, THU: +1, FRI: -1, SAT: -1, SUN: -2})
+
 
 class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays, StaticHolidays):
     """
     References:
         - https://en.wikipedia.org/wiki/Public_holidays_in_Taiwan
-        - https://www.officeholidays.com/countries/taiwan
+        - `2025 <https://www.dgpa.gov.tw/en/information?uid=353&pid=11979>`_
         - `2024 <https://www.dgpa.gov.tw/en/information?uid=353&pid=11402>`_
         - `2023 <https://www.dgpa.gov.tw/en/information?uid=353&pid=11016>`_
         - `2022 <https://www.dgpa.gov.tw/en/information?uid=353&pid=10659>`_
@@ -52,6 +70,7 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
     observed_label = tr("%s（慶祝）")
     default_language = "zh_TW"
     supported_languages = ("en_US", "th", "zh_CN", "zh_TW")
+    start_year = 1912
 
     def __init__(self, *args, **kwargs):
         ChineseCalendarHolidays.__init__(self)
@@ -61,18 +80,23 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
         super().__init__(*args, **kwargs)
 
     def _populate_observed(
-        self, dts: Set[date], rule: ObservedRule = None, since: int = 2015
+        self, dts: set[date], rule: ObservedRule = None, since: int = 2015
     ) -> None:
         if self._year < since:
             return None
+
+        childrens_day = self.tr("兒童節")
         for dt in sorted(dts):
-            for name in self.get_list(dt):
-                self._add_observed(dt, name, rule)
+            names = self.get_list(dt)
+            for name in names:
+                self._add_observed(
+                    dt,
+                    name,
+                    # Children's Day falls on the same day as Tomb Sweeping Day.
+                    CHILDRENS_DAY_RULE if name == childrens_day and len(names) > 1 else rule,
+                )
 
     def _populate_public_holidays(self):
-        if self._year <= 1911:
-            return None
-
         dts_observed = set()
         dts_observed_forward = set()
 
@@ -97,9 +121,7 @@ class Taiwan(ObservedHolidayBase, ChineseCalendarHolidays, InternationalHolidays
 
         if 1990 <= self._year <= 1999 or self._year >= 2011:
             # Children's Day.
-            apr_4 = self._add_holiday_apr_4(tr("兒童節"))
-            if self._year != 2021:
-                dts_observed.add(apr_4)
+            dts_observed.add(self._add_holiday_apr_4(tr("兒童節")))
 
         if self._year >= 1972:
             # Tomb Sweeping Day.
@@ -185,12 +207,9 @@ class TaiwanStaticHolidays:
             (OCT, 9, SEP, 23),
         ),
         2024: (FEB, 8, FEB, 17),
+        2025: (JAN, 27, FEB, 8),
     }
 
     special_public_holidays_observed = {
         2013: (APR, 5, childrens_day),
-        2016: (APR, 5, childrens_day),
-        2017: (APR, 3, childrens_day),
-        2021: (APR, 2, childrens_day),
-        2024: (APR, 5, childrens_day),
     }
