@@ -7,7 +7,7 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 from gettext import gettext as tr
@@ -31,10 +31,11 @@ class TimorLeste(
     References:
     - https://mj.gov.tl/jornal/lawsTL/RDTL-Law/RDTL-Laws/Law-2005-10.pdf  # 2005 Law
     - http://timor-leste.gov.tl/?p=14494&lang=en  # 2016 Amendment
+    - http://timor-leste.gov.tl/?p=30266&lang=en  # 2022
     - http://timor-leste.gov.tl/?p=31750&lang=en  # 2023 (en_US)
     - http://timor-leste.gov.tl/?p=31750&lang=pt  # 2023 (pt_PT)
     - http://timor-leste.gov.tl/?p=31750&lang=tp  # 2023 (tet)
-    - http://timor-leste.gov.tl/?p=30266&lang=en  # 2022
+    - http://timor-leste.gov.tl/?p=35833&lang=en  # 2024
 
     Limitations:
 
@@ -47,6 +48,8 @@ class TimorLeste(
     # %s (estimated).
     estimated_label = tr("%s (aproximada)")
     supported_languages = ("en_US", "pt_TL", "tet")
+    # Law No. 10/2005 Of 10 August, Public Holidays and Official Commemorative Dates.
+    start_year = 2006
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -56,10 +59,6 @@ class TimorLeste(
         super().__init__(*args, **kwargs)
 
     def _populate_public_holidays(self):
-        # Law No. 10/2005 Of 10 August, Public Holidays and Official Commemorative Dates.
-        if self._year <= 2005:
-            return None
-
         # Fixed Date Public Holidays.
 
         # New Year's Day.
@@ -130,20 +129,16 @@ class TimorLeste(
         # Holy Friday.
         self._add_good_friday(tr("Sexta-Feira Santa"))
 
-        # Idul Fitri.
+        # Eid al-Fitr.
         self._add_eid_al_fitr_day(tr("Idul Fitri"))
 
         # Corpus Christi.
         self._add_corpus_christi_day(tr("Festa do Corpo de Deus"))
 
-        # Idul Adha.
+        # Eid al-Adha.
         self._add_eid_al_adha_day(tr("Idul Adha"))
 
     def _populate_workday_holidays(self):
-        # Law No. 10/2005 Of 10 August, Public Holidays and Official Commemorative Dates.
-        if self._year <= 2005:
-            return None
-
         # Fixed Date Government Holidays.
 
         # World Children's Day.
@@ -201,6 +196,7 @@ class TimorLesteIslamicHolidays(_CustomIslamicHolidays):
         2021: (JUL, 19),
         2022: (JUL, 9),
         2023: (JUN, 29),
+        2024: (JUN, 17),
     }
 
     EID_AL_FITR_DATES = {
@@ -217,6 +213,7 @@ class TimorLesteIslamicHolidays(_CustomIslamicHolidays):
         2021: (MAY, 13),
         2022: (MAY, 2),
         2023: (APR, 22),
+        2024: (APR, 10),
     }
 
 
@@ -232,6 +229,9 @@ class TimorLesteStaticHolidays:
     # Parliamentary Election Day.
     parliamentary_election = tr("Dia de Eleições Parlamentares")
 
+    # Local Election Day.
+    local_election = tr("Dia de eleições locais")
+
     # Centenary of the Revolt of Dom Boaventura.
     dom_boaventura_centenary = tr("Centenário da Revolta de Dom Boaventura")
 
@@ -241,6 +241,12 @@ class TimorLesteStaticHolidays:
     # 20th Anniversary Celebrations of the Popular Consultation.
     popular_consultation_20th = tr("Celebrações do 20.º Aniversário da Consulta Popular")
 
+    # 25th Anniversary Celebrations of the Popular Consultation.
+    popular_consultation_25th = tr("Celebrações do 25.º Aniversário da Consulta Popular")
+
+    # Visit of His Holiness Pope Francis to Timor-Leste.
+    pope_francis_visit = tr("Visita de Sua Santidade o Papa Francisco a Timor-Leste")
+
     special_government_holidays = {
         2010: (
             # http://timor-leste.gov.tl/?p=4183&lang=en
@@ -395,20 +401,28 @@ class TimorLesteStaticHolidays:
             (JAN, 2, special_national_holidays),
             # http://timor-leste.gov.tl/?p=23607&lang=en
             (FEB, 26, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=25455&lang=en
+            (AUG, 20, special_national_holidays),
             # http://timor-leste.gov.tl/?p=25502&lang=en
             (AUG, 31, special_national_holidays),
             # http://timor-leste.gov.tl/?p=26030&lang=en
             (NOV, 3, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=26365&lang=en
+            (DEC, 24, special_national_holidays),
         ),
         2021: (
             # http://timor-leste.gov.tl/?p=26865&lang=en
             (FEB, 12, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=26896&lang=en
+            (FEB, 17, special_national_holidays),
             # http://timor-leste.gov.tl/?p=29682&lang=en
             (NOV, 3, special_national_holidays),
         ),
         2022: (
             # http://timor-leste.gov.tl/?p=30029&lang=en
             (FEB, 1, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=30194&lang=en
+            (MAR, 2, special_national_holidays),
             # http://timor-leste.gov.tl/?p=30254&lang=en
             (MAR, 18, presidential_election),
             # http://timor-leste.gov.tl/?p=30429&lang=en
@@ -416,11 +430,57 @@ class TimorLesteStaticHolidays:
             (APR, 18, presidential_election),
             (APR, 19, presidential_election),
             (APR, 20, presidential_election),
+            # https://timor-leste.gov.tl/?p=31107&lang=en
+            (AUG, 29, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=31152&lang=en
+            (SEP, 6, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=31404&lang=en
+            (OCT, 31, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=31574&lang=en
+            (DEC, 9, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=31633&lang=en
+            (DEC, 26, special_national_holidays),
         ),
         2023: (
             # http://timor-leste.gov.tl/?p=31641&lang=en
             (JAN, 2, special_national_holidays),
             # http://timor-leste.gov.tl/?p=31798&lang=en
             (JAN, 23, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=32191&lang=en
+            (FEB, 22, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=32561&lang=en
+            (APR, 6, special_national_holidays),
+            (APR, 10, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=32590&lang=en
+            (APR, 20, special_national_holidays),
+            (APR, 21, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=32617&lang=en
+            (MAY, 19, parliamentary_election),
+            (MAY, 22, parliamentary_election),
+            # https://timor-leste.gov.tl/?p=34792&lang=en
+            (OCT, 27, local_election),
+            # https://timor-leste.gov.tl/?p=35060&lang=en
+            (NOV, 13, local_election),
+            # https://timor-leste.gov.tl/?p=35627&lang=en&
+            (DEC, 26, special_national_holidays),
+        ),
+        2024: (
+            # https://timor-leste.gov.tl/?p=35627&lang=en
+            (JAN, 2, special_national_holidays),
+            # http://timor-leste.gov.tl/?p=36002&lang=en
+            (FEB, 14, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=36859&lang=en
+            (MAR, 28, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=39062&lang=en
+            (AUG, 28, popular_consultation_25th),
+            (AUG, 29, popular_consultation_25th),
+            # https://timor-leste.gov.tl/?p=39068&lang=en
+            (SEP, 9, pope_francis_visit),
+            (SEP, 10, pope_francis_visit),
+            (SEP, 11, pope_francis_visit),
+            # https://timor-leste.gov.tl/?p=40592&lang=en
+            (OCT, 31, special_national_holidays),
+            # https://timor-leste.gov.tl/?p=40955&lang=en
+            (NOV, 29, special_national_holidays),
         ),
     }
