@@ -7,16 +7,17 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
-from typing import Tuple, Union
+from typing import Union
 
-from holidays.calendars.gregorian import DEC
+from holidays.calendars.gregorian import MON, TUE, WED, THU, FRI, SAT, SUN
 from holidays.constants import PUBLIC, UNOFFICIAL
 from holidays.groups import ChristianHolidays, InternationalHolidays
 from holidays.observed_holiday_base import (
     ObservedHolidayBase,
+    ObservedRule,
     MON_TO_NEXT_TUE,
     FRI_TO_PREV_THU,
     SAT_TO_PREV_FRI,
@@ -25,28 +26,68 @@ from holidays.observed_holiday_base import (
     SAT_SUN_TO_NEXT_MON,
 )
 
+GA_IN_WASHINGTON_BIRTHDAY = ObservedRule(
+    {MON: +1, TUE: -1, WED: -1, THU: +1, FRI: -1, SAT: -2, SUN: -2}
+)
+
 
 class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
     """
     https://en.wikipedia.org/wiki/Public_holidays_in_the_United_States
 
     For Northern Mariana Islands (subdivision MP):
-    - https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/  # noqa: E501
-    - https://webcache.googleusercontent.com/search?q=cache:C17_7FBgPtQJ:https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/&hl=en&gl=sg&strip=1&vwsrc=0  # noqa: E501
+    - https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/
+    - https://webcache.googleusercontent.com/search?q=cache:C17_7FBgPtQJ:https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/&hl=en&gl=sg&strip=1&vwsrc=0
 
     Columbus Day / Indigenous Peoples' Day history:
-    - https://www.pewresearch.org/short-reads/2023/10/05/working-on-columbus-day-or-indigenous-peoples-day-it-depends-on-where-your-job-is/  # noqa: E501
+    - https://www.pewresearch.org/short-reads/2023/10/05/working-on-columbus-day-or-indigenous-peoples-day-it-depends-on-where-your-job-is/
     - https://www.officeholidays.com/holidays/usa/columbus-day-state-guide
     - https://en.wikipedia.org/wiki/Indigenous_Peoples%27_Day_(United_States)
     - https://www.sos.ri.gov/divisions/civics-and-education/reference-desk/ri-state-holidays
-    - https://web.archive.org/web/20080831103521/http://www.dpa.ca.gov/personnel-policies/holidays.htm  # noqa: E501
+    - https://web.archive.org/web/20080831103521/http://www.dpa.ca.gov/personnel-policies/holidays.htm
 
+    Frances Xavier Cabrini Day:
+        - https://leg.colorado.gov/sites/default/files/2020a_1031_signed.pdf
+
+    Washington's Birthday:
+        - AK: https://doa.alaska.gov/calendar/
+        - AL: https://admincode.legislature.state.al.us/administrative-code/670-X-12-.01
+        - AR: https://arkleg.state.ar.us/Home/FTPDocument?path=/ACTS/2001/Public/ACT304.pdf
+        - AZ: https://www.azleg.gov/ars/1/00301.htm
+        - CA: https://www.sos.ca.gov/state-holidays
+        - CO: https://leg.colorado.gov/sites/default/files/images/olls/crs2023-title-24.pdf
+        - GA: https://www.gasupreme.us/court-information/holidays-2/
+        - HI: https://www.capitol.hawaii.gov/hrscurrent/Vol01_Ch0001-0042F/HRS0008/HRS_0008-0001.htm
+        - ID: https://idaho.gov/government/state-holidays/
+        - IN: https://digital.statelib.lib.in.us/infoexpress/holidays.aspx
+              https://www.in.gov/spd/benefits/state-holidays/
+        - MD: https://msa.maryland.gov/msa/mdmanual/01glance/html/holidayl.html
+        - MN: https://www.revisor.mn.gov/statutes/cite/645.44
+        - MT: https://archive.legmt.gov/bills/mca/title_0010/chapter_0010/part_0020/section_0160/0010-0010-0020-0160.html
+        - NJ: https://nj.gov/nj/about/facts/holidays/
+        - OH: https://codes.ohio.gov/ohio-revised-code/section-1.14
+        - OK: https://oklahoma.gov/omes/divisions/human-capital-management/employee-benefits/leave-holidays/holidays.html
+        - OR: https://www.oregonlegislature.gov/bills_laws/ors/ors187.html
+        - PA: https://www.legis.state.pa.us/WU01/LI/LI/US/PDF/1893/0/0138..PDF
+        - PR: https://en.wikipedia.org/wiki/Public_holidays_in_Puerto_Rico
+        - SC: https://www.scstatehouse.gov/code/t53c005.php
+        - TN: https://www.tn.gov/about-tn/state-holidays.html
+        - TX: https://www.tsl.texas.gov/ref/abouttx/holidays
+        - UT: https://le.utah.gov/xcode/Title63G/Chapter1/63G-1-S301.html
+        - VA: https://law.lis.virginia.gov/vacode/title2.2/chapter33/section2.2-3300/
+        - VT: https://legislature.vermont.gov/statutes/section/01/007/00371
+        - WA: https://app.leg.wa.gov/rcw/default.aspx?cite=1.16.050
+        - WV: https://code.wvlegislature.gov/2-2-1/
+        - WY: https://ai.wyo.gov/about-us/state-holidays-and-office-closures
+
+    American Samoa holidays:
+        - https://asbar.org/code-annotated/1-0501-public-holidays/
     """
 
     country = "US"
     supported_categories = (PUBLIC, UNOFFICIAL)
     observed_label = "%s (observed)"
-    subdivisions: Union[Tuple[()], Tuple[str, ...]] = (
+    subdivisions: Union[tuple[()], tuple[str, ...]] = (
         "AK",  # Alaska.
         "AL",  # Alabama.
         "AR",  # Arkansas.
@@ -111,6 +152,7 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         "MH",
         "PW",
     )
+    start_year = 1777
 
     def __init__(self, *args, **kwargs):
         ChristianHolidays.__init__(self)
@@ -180,14 +222,38 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
 
         # Washington's Birthday
         if self._year >= 1879 and self.subdiv not in {
+            "AK",
             "AL",
             "AR",
+            "AZ",
+            "CA",
+            "CO",
             "DE",
             "FL",
             "GA",
+            "HI",
+            "ID",
+            "IN",
+            "MD",
+            "MN",
+            "MT",
+            "NJ",
             "NM",
+            "OH",
+            "OK",
+            "OR",
+            "PA",
             "PR",
+            "SC",
+            "TN",
+            "TX",
+            "UT",
+            "VA",
             "VI",
+            "VT",
+            "WA",
+            "WV",
+            "WY",
         }:
             name = "Washington's Birthday"
             if self._year >= 1971:
@@ -228,8 +294,13 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         super()._populate_subdiv_holidays()
 
     def _populate_subdiv_ak_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Seward's Day
-        if self._year >= 1918:
+        # No observance in 1921: https://chroniclingamerica.loc.gov/lccn/sn86072239/1922-03-29/ed-1/seq-8/
+        if self._year >= 1918 and self._year != 1921:
             name = "Seward's Day"
             if self._year >= 1955:
                 self._add_holiday_last_mon_of_mar(name)
@@ -243,7 +314,8 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             )
 
         # Alaska Day
-        if self._year >= 1867:
+        # https://web.archive.org/web/20120502232826/http://www.alaskadispatch.com/article/happy-alaska-day-great-land
+        if self._year >= 1917:
             self._add_observed(self._add_holiday_oct_18("Alaska Day"))
 
     def _populate_subdiv_al_public_holidays(self):
@@ -277,12 +349,11 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
     def _populate_subdiv_ar_public_holidays(self):
         # Martin Luther King Jr. Day
         if self._year >= 1986:
-            name = (
+            self._add_holiday_3rd_mon_of_jan(
                 "Martin Luther King Jr. Day"
                 if self._year >= 2018
                 else "Dr. Martin Luther King Jr. and Robert E. Lee's Birthdays"
             )
-            self._add_holiday_3rd_mon_of_jan(name)
 
         # Washington's Birthday
         name = "George Washington's Birthday and Daisy Gatson Bates Day"
@@ -292,19 +363,35 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_holiday_feb_22(name)
 
     def _populate_subdiv_as_public_holidays(self):
-        # Christmas Eve
-        self._add_christmas_eve_holiday()
+        # American Samoa Flag Day
+        if self._year >= 1901:
+            self._add_observed(self._add_holiday_apr_17("American Samoa Flag Day"))
+
+        # Manu'a Islands Cession Day
+        if self._year >= 1983:
+            self._add_observed(self._add_holiday_jul_16("Manu'a Islands Cession Day"))
+
+        # White Sunday
+        self._add_holiday_2nd_sun_of_oct("White Sunday")
 
     def _populate_subdiv_az_public_holidays(self):
         # Martin Luther King Jr. Day
         if self._year >= 1986:
             self._add_holiday_3rd_mon_of_jan("Dr. Martin Luther King Jr. / Civil Rights Day")
 
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Lincoln/Washington Presidents' Day")
+
     def _populate_subdiv_ca_public_holidays(self):
         # Lincoln's Birthday
         if 1971 <= self._year <= 2009:
             self._add_observed(self._add_holiday_feb_12("Lincoln's Birthday"))
 
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Susan B. Anthony Day
         if self._year >= 2014:
             self._add_holiday_feb_15("Susan B. Anthony Day")
@@ -322,10 +409,18 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_holiday_1_day_past_4th_thu_of_nov("Day After Thanksgiving")
 
     def _populate_subdiv_co_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Washington-Lincoln Day")
+
         # Cesar Chavez Day
         if self._year >= 2001:
             self._add_holiday_mar_31("Cesar Chavez Day")
 
+        # Frances Xavier Cabrini Day
+        if self._year >= 2020:
+            self._add_holiday_1st_mon_of_oct("Frances Xavier Cabrini Day")
+
     def _populate_subdiv_ct_public_holidays(self):
         # Lincoln's Birthday
         if self._year >= 1971:
@@ -398,11 +493,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             )
 
         # Washington's Birthday
-        name = "Washington's Birthday"
-        if self._is_wednesday(DEC, 24):
-            self._add_holiday_dec_26(name)
-        else:
-            self._add_holiday_dec_24(name)
+        self._add_holiday(
+            "Washington's Birthday",
+            self._get_observed_date(self._christmas_day, rule=GA_IN_WASHINGTON_BIRTHDAY),
+        )
 
     def _populate_subdiv_gu_public_holidays(self):
         # Guam Discovery Day
@@ -423,6 +517,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         self._add_immaculate_conception_day("Lady of Camarin Day")
 
     def _populate_subdiv_hi_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Prince Jonah Kuhio Kalanianaole Day
         if self._year >= 1949:
             self._add_observed(self._add_holiday_mar_26("Prince Jonah Kuhio Kalanianaole Day"))
@@ -452,9 +550,13 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_holiday_3rd_mon_of_jan(
                 "Martin Luther King Jr. / Idaho Human Rights Day"
                 if self._year >= 2006
-                else "Martin Luther King Jr. Day",
+                else "Martin Luther King Jr. Day"
             )
 
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
     def _populate_subdiv_il_public_holidays(self):
         # Lincoln's Birthday
         if self._year >= 1971:
@@ -484,6 +586,12 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         if self._year >= 2010:
             self._add_holiday_1_day_past_4th_thu_of_nov("Lincoln's Birthday")
 
+        # Washington's Birthday
+        self._add_holiday(
+            "Washington's Birthday",
+            self._get_observed_date(self._christmas_day, rule=GA_IN_WASHINGTON_BIRTHDAY),
+        )
+
     def _populate_subdiv_ks_public_holidays(self):
         # Christmas Eve
         if self._year >= 2013:
@@ -545,6 +653,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
                 rule=SUN_TO_NEXT_MON,
             )
 
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # American Indian Heritage Day
         if self._year >= 2008:
             self._add_holiday_1_day_past_4th_thu_of_nov("American Indian Heritage Day")
@@ -573,7 +685,9 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_observed(self._add_new_years_eve("New Year's Eve"))
 
     def _populate_subdiv_mn_public_holidays(self):
-        pass
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Washington's and Lincoln's Birthday")
 
     def _populate_subdiv_mo_public_holidays(self):
         # Truman Day
@@ -604,14 +718,18 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         # Martin Luther King Jr. Day
         if self._year >= 1986:
             self._add_holiday_3rd_mon_of_jan(
-                "Dr. Martin Luther King Jr. and Robert E. Lee's Birthdays",
+                "Dr. Martin Luther King Jr. and Robert E. Lee's Birthdays"
             )
 
         # Confederate Memorial Day
         if self._year >= 1866:
-            self._add_holiday_4th_mon_of_apr("Confederate Memorial Day")
+            self._add_holiday_last_mon_of_apr("Confederate Memorial Day")
 
     def _populate_subdiv_mt_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Lincoln's and Washington's Birthdays")
+
         # Election Day
         if self._year >= 2008 and self._year % 2 == 0:
             self._add_holiday_1_day_past_1st_mon_of_nov("Election Day")
@@ -675,6 +793,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         if self._year >= 1971:
             self._add_observed(self._add_holiday_feb_12("Lincoln's Birthday"))
 
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents Day")
+
         # Good Friday
         self._add_good_friday("Good Friday")
 
@@ -719,17 +841,29 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_holiday_1_day_past_1st_mon_of_nov("Election Day")
 
     def _populate_subdiv_oh_public_holidays(self):
-        pass
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Washington-Lincoln Day")
 
     def _populate_subdiv_ok_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Day After Thanksgiving
         if self._year >= 1975:
             self._add_holiday_1_day_past_4th_thu_of_nov("Day After Thanksgiving")
 
     def _populate_subdiv_or_public_holidays(self):
-        pass
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents Day")
 
     def _populate_subdiv_pa_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Day After Thanksgiving
         self._add_holiday_1_day_past_4th_thu_of_nov("Day After Thanksgiving")
 
@@ -764,6 +898,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             )
 
     def _populate_subdiv_sc_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("President's Day")
+
         # Confederate Memorial Day
         if self._year >= 1866:
             self._add_holiday_4th_mon_of_apr("Confederate Memorial Day")
@@ -778,6 +916,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
                 self._add_columbus_day(name)
 
     def _populate_subdiv_tn_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("President's Day")
+
         # Good Friday
         self._add_good_friday("Good Friday")
 
@@ -786,6 +928,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         if self._year >= 1931:
             self._add_holiday_jan_19("Confederate Memorial Day")
 
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Texas Independence Day
         if self._year >= 1874:
             self._add_holiday_mar_2("Texas Independence Day")
@@ -825,6 +971,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         pass
 
     def _populate_subdiv_ut_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Washington and Lincoln Day")
+
         # Pioneer Day
         if self._year >= 1849:
             self._add_observed(self._add_holiday_jul_24("Pioneer Day"))
@@ -849,6 +999,11 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
                 else self._add_holiday_mar_4(name),
                 rule=SUN_TO_NEXT_MON,
             )
+
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("George Washington Day")
+
         # Indigenous Peoples' Day
         if self._year >= 1971:
             self._add_holiday_2nd_mon_of_oct(
@@ -896,6 +1051,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         self._add_christmas_day_two("Christmas Second Day")
 
     def _populate_subdiv_vt_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # Town Meeting Day
         if self._year >= 1800:
             self._add_holiday_1st_tue_of_mar("Town Meeting Day")
@@ -905,7 +1064,9 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_observed(self._add_holiday_aug_16("Bennington Battle Day"))
 
     def _populate_subdiv_wa_public_holidays(self):
-        pass
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
 
     def _populate_subdiv_wi_public_holidays(self):
         # Susan B. Anthony Day
@@ -920,6 +1081,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_observed(self._add_new_years_eve("New Year's Eve"))
 
     def _populate_subdiv_wv_public_holidays(self):
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("Presidents' Day")
+
         # West Virginia Day
         if self._year >= 1927:
             self._add_observed(self._add_holiday_jun_20("West Virginia Day"))
@@ -933,7 +1098,9 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
             self._add_holiday_1_day_past_4th_thu_of_nov("Day After Thanksgiving")
 
     def _populate_subdiv_wy_public_holidays(self):
-        pass
+        # Washington's Birthday
+        if self._year >= 1971:
+            self._add_holiday_3rd_mon_of_feb("President's Day")
 
     def _populate_unofficial_holidays(self):
         # Very common celebrated cultural days, but no official observance.
@@ -946,10 +1113,10 @@ class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays
         if self._year >= 1847:
             self._add_holiday_feb_14("Valentine's Day")
 
-        # St. Patrick's Day
+        # Saint Patrick's Day
         # Started in Boston in 1737 for the US.
 
-        self._add_holiday_mar_17("St. Patrick's Day")
+        self._add_holiday_mar_17("Saint Patrick's Day")
 
         # Halloween
         # Halloween began in the US sometime around the 19th century.
