@@ -7,10 +7,12 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 # flake8: noqa: F401
 
-from .european_central_bank import EuropeanCentralBank, ECB, TAR
-from .ny_stock_exchange import NewYorkStockExchange, NYSE, XNYS
+from .brasil_bolsa_balcao import BrasilBolsaBalcao, BVMF, B3
+from .european_central_bank import EuropeanCentralBank, XECB, ECB, TAR
+from .ice_futures_europe import ICEFuturesEurope, IFEU
+from .ny_stock_exchange import NewYorkStockExchange, XNYS, NYSE
