@@ -7,24 +7,24 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 __all__ = ("DateLike", "HolidayBase", "HolidaySum")
 
 import copy
-import re
 import warnings
+from bisect import bisect_left, bisect_right
 from calendar import isleap
+from collections.abc import Iterable
 from datetime import date, datetime, timedelta, timezone
 from functools import cached_property
 from gettext import gettext, translation
 from pathlib import Path
-from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union, cast
+from typing import Any, Literal, Optional, Union, cast
 
 from dateutil.parser import parse
 
-from holidays.calendars import gregorian
 from holidays.calendars.gregorian import (
     MON,
     TUE,
@@ -33,24 +33,28 @@ from holidays.calendars.gregorian import (
     FRI,
     SAT,
     SUN,
+    _timedelta,
     _get_nth_weekday_from,
     _get_nth_weekday_of_month,
+    DAYS,
+    MONTHS,
+    WEEKDAYS,
 )
-from holidays.constants import HOLIDAY_NAME_DELIMITER, PUBLIC
+from holidays.constants import HOLIDAY_NAME_DELIMITER, PUBLIC, DEFAULT_START_YEAR, DEFAULT_END_YEAR
 from holidays.helpers import _normalize_arguments, _normalize_tuple
 
 CategoryArg = Union[str, Iterable[str]]
-DateArg = Union[date, Tuple[int, int]]
+DateArg = Union[date, tuple[int, int]]
 DateLike = Union[date, datetime, str, float, int]
-SpecialHoliday = Union[Tuple[int, int, str], Tuple[Tuple[int, int, str], ...]]
+SpecialHoliday = Union[tuple[int, int, str], tuple[tuple[int, int, str], ...]]
 SubstitutedHoliday = Union[
-    Union[Tuple[int, int, int, int], Tuple[int, int, int, int, int]],
-    Tuple[Union[Tuple[int, int, int, int], Tuple[int, int, int, int, int]], ...],
+    Union[tuple[int, int, int, int], tuple[int, int, int, int, int]],
+    tuple[Union[tuple[int, int, int, int], tuple[int, int, int, int, int]], ...],
 ]
 YearArg = Union[int, Iterable[int]]
 
 
-class HolidayBase(Dict[date, str]):
+class HolidayBase(dict[date, str]):
     """
     A dict-like object containing the holidays for a specific country (and
     province or state if so initiated); inherits the dict class (so behaves
@@ -208,12 +212,12 @@ class HolidayBase(Dict[date, str]):
     """The country's ISO 3166-1 alpha-2 code."""
     market: str
     """The market's ISO 3166-1 alpha-2 code."""
-    subdivisions: Tuple[str, ...] = ()
+    subdivisions: tuple[str, ...] = ()
     """The subdivisions supported for this country (see documentation)."""
-    subdivisions_aliases: Dict[str, str] = {}
+    subdivisions_aliases: dict[str, str] = {}
     """Aliases for the ISO 3166-2 subdivision codes with the key as alias and
     the value the ISO 3166-2 subdivision code."""
-    years: Set[int]
+    years: set[int]
     """The years calculated."""
     expand: bool
     """Whether the entire year is calculated when one date from that year
@@ -222,24 +226,32 @@ class HolidayBase(Dict[date, str]):
     """Whether dates when public holiday are observed are included."""
     subdiv: Optional[str] = None
     """The subdiv requested as ISO 3166-2 code or one of the aliases."""
-    special_holidays: Dict[int, Union[SpecialHoliday, SubstitutedHoliday]] = {}
+    special_holidays: dict[int, Union[SpecialHoliday, SubstitutedHoliday]] = {}
     """A list of the country-wide special (as opposite to regular) holidays for
     a specific year."""
-    _deprecated_subdivisions: Tuple[str, ...] = ()
+    _deprecated_subdivisions: tuple[str, ...] = ()
     """Other subdivisions whose names are deprecated or aliases of the official
     ones."""
-    weekend: Set[int] = {SAT, SUN}
+    weekend: set[int] = {SAT, SUN}
     """Country weekend days."""
+    weekend_workdays: set[date]
+    """Working days moved to weekends."""
     default_category: str = PUBLIC
     """The entity category used by default."""
     default_language: Optional[str] = None
     """The entity language used by default."""
-    categories: Set[str] = set()
+    categories: set[str] = set()
     """Requested holiday categories."""
-    supported_categories: Tuple[str, ...] = (PUBLIC,)
+    supported_categories: tuple[str, ...] = (PUBLIC,)
     """All holiday categories supported by this entity."""
-    supported_languages: Tuple[str, ...] = ()
+    supported_languages: tuple[str, ...] = ()
     """All languages supported by this entity."""
+    start_year: int = DEFAULT_START_YEAR
+    """Start year of holidays presence for this entity."""
+    end_year: int = DEFAULT_END_YEAR
+    """End year of holidays presence for this entity."""
+    parent_entity: Optional[type["HolidayBase"]] = None
+    """Optional parent entity to reference as a base."""
 
     def __init__(
         self,
@@ -320,8 +332,7 @@ class HolidayBase(Dict[date, str]):
             # Deprecated arguments.
             if prov_state := prov or state:
                 warnings.warn(
-                    "Arguments prov and state are deprecated, use "
-                    f"subdiv='{prov_state}' instead.",
+                    f"Arguments prov and state are deprecated, use subdiv='{prov_state}' instead.",
                     DeprecationWarning,
                 )
 
@@ -353,18 +364,35 @@ class HolidayBase(Dict[date, str]):
         self.language = language.lower() if language else None
         self.observed = observed
         self.subdiv = subdiv
+        self.weekend_workdays = getattr(self, "weekend_workdays", set())
 
         supported_languages = set(self.supported_languages)
-        self.tr = (
-            translation(
+        if self._entity_code is not None:
+            fallback = language not in supported_languages
+            languages = [language] if language in supported_languages else None
+            locale_directory = str(Path(__file__).with_name("locale"))
+
+            # Add entity native content translations.
+            entity_translation = translation(
                 self._entity_code,
-                fallback=language not in supported_languages,
-                languages=[language] if language in supported_languages else None,
-                localedir=str(Path(__file__).with_name("locale")),
-            ).gettext
-            if self._entity_code is not None
-            else gettext
-        )
+                fallback=fallback,
+                languages=languages,
+                localedir=locale_directory,
+            )
+            # Add a fallback if entity has parent translations.
+            if parent_entity := self.parent_entity:
+                entity_translation.add_fallback(
+                    translation(
+                        parent_entity.country or parent_entity.market,
+                        fallback=fallback,
+                        languages=languages,
+                        localedir=locale_directory,
+                    )
+                )
+            self.tr = entity_translation.gettext
+        else:
+            self.tr = gettext
+
         self.years = _normalize_arguments(int, years)
 
         # Populate holidays.
@@ -409,7 +437,7 @@ class HolidayBase(Dict[date, str]):
         if not isinstance(key, (date, datetime, float, int, str)):
             raise TypeError(f"Cannot convert type '{type(key)}' to date.")
 
-        return dict.__contains__(cast("Dict[Any, Any]", self), self.__keytransform__(key))
+        return dict.__contains__(cast("dict[Any, Any]", self), self.__keytransform__(key))
 
     def __eq__(self, other: object) -> bool:
         if not isinstance(other, HolidayBase):
@@ -419,7 +447,7 @@ class HolidayBase(Dict[date, str]):
             if getattr(self, attribute_name, None) != getattr(other, attribute_name, None):
                 return False
 
-        return dict.__eq__(cast("Dict[Any, Any]", self), other)
+        return dict.__eq__(cast("dict[Any, Any]", self), other)
 
     def __getattr__(self, name):
         try:
@@ -427,77 +455,106 @@ class HolidayBase(Dict[date, str]):
         except AttributeError as e:
             # This part is responsible for _add_holiday_* syntactic sugar support.
             add_holiday_prefix = "_add_holiday_"
-            # Raise early if prefix doesn't match to avoid regex checks.
+            # Raise early if prefix doesn't match to avoid patterns checks.
             if name[: len(add_holiday_prefix)] != add_holiday_prefix:
                 raise e
 
-            # Handle <month> <day> patterns (e.g., _add_holiday_jun_15()).
-            month_day = re.match(r"_add_holiday_(\w{3})_(\d{1,2})", name)
-            if month_day:
-                month, day = month_day.groups()
-                return lambda name: self._add_holiday(
-                    name,
-                    date(self._year, getattr(gregorian, month.upper()), int(day)),
-                )
+            tokens = name.split("_")
 
-            # Handle <last/nth> <weekday> of <month> patterns (e.g.,
-            # _add_holiday_last_mon_of_aug() or _add_holiday_3rd_fri_of_aug()).
-            nth_weekday_of_month = re.match(
-                r"_add_holiday_(last|\d\w{2})_(\w{3})_of_(\w{3})", name
-            )
-            if nth_weekday_of_month:
-                number, weekday, month = nth_weekday_of_month.groups()
-                return lambda name: self._add_holiday(
-                    name,
-                    _get_nth_weekday_of_month(
-                        -1 if number == "last" else +int(re.sub(r"\D", "", number)),
-                        getattr(gregorian, weekday.upper()),
-                        getattr(gregorian, month.upper()),
-                        self._year,
-                    ),
-                )
+            # Handle <month> <day> patterns (e.g., _add_holiday_jun_15()).
+            if len(tokens) == 5:
+                *_, month, day = tokens
+                if month in MONTHS and day in DAYS:
+                    return lambda name: self._add_holiday(
+                        name, date(self._year, MONTHS[month], int(day))
+                    )
+
+            elif len(tokens) == 7:
+                # Handle <last/nth> <weekday> of <month> patterns (e.g.,
+                # _add_holiday_last_mon_of_aug() or _add_holiday_3rd_fri_of_aug()).
+                *_, number, weekday, of, month = tokens
+                if (
+                    of == "of"
+                    and (number == "last" or number[0].isdigit())
+                    and month in MONTHS
+                    and weekday in WEEKDAYS
+                ):
+                    return lambda name: self._add_holiday(
+                        name,
+                        _get_nth_weekday_of_month(
+                            -1 if number == "last" else int(number[0]),
+                            WEEKDAYS[weekday],
+                            MONTHS[month],
+                            self._year,
+                        ),
+                    )
+
+                # Handle <n> days <past/prior> easter patterns (e.g.,
+                # _add_holiday_8_days_past_easter() or
+                # _add_holiday_5_days_prior_easter()).
+                *_, days, unit, delta_direction, easter = tokens
+                if (
+                    unit in {"day", "days"}
+                    and delta_direction in {"past", "prior"}
+                    and easter == "easter"
+                    and len(days) < 3
+                    and days.isdigit()
+                ):
+                    return lambda name: self._add_holiday(
+                        name,
+                        _timedelta(
+                            self._easter_sunday,
+                            +int(days) if delta_direction == "past" else -int(days),
+                        ),
+                    )
 
             # Handle <n> day(s) <past/prior> <last/<nth> <weekday> of <month> patterns (e.g.,
             # _add_holiday_1_day_past_1st_fri_of_aug() or
             # _add_holiday_5_days_prior_last_fri_of_aug()).
-            nth_weekday_of_month_with_delta = re.match(
-                r"_add_holiday_(\d{1,2})_days?_(past|prior)_(last|\d\w{2})_(\w{3})_of_(\w{3})",
-                name,
-            )
-            if nth_weekday_of_month_with_delta:
-                (
-                    days,
-                    delta_direction,
-                    number,
-                    weekday,
-                    month,
-                ) = nth_weekday_of_month_with_delta.groups()
-                return lambda name: self._add_holiday(
-                    name,
-                    _get_nth_weekday_of_month(
-                        -1 if number == "last" else +int(re.sub(r"\D", "", number)),
-                        getattr(gregorian, weekday.upper()),
-                        getattr(gregorian, month.upper()),
-                        self._year,
+            elif len(tokens) == 10:
+                *_, days, unit, delta_direction, number, weekday, of, month = tokens
+                if (
+                    unit in {"day", "days"}
+                    and delta_direction in {"past", "prior"}
+                    and of == "of"
+                    and len(days) < 3
+                    and days.isdigit()
+                    and (number == "last" or number[0].isdigit())
+                    and month in MONTHS
+                    and weekday in WEEKDAYS
+                ):
+                    return lambda name: self._add_holiday(
+                        name,
+                        _timedelta(
+                            _get_nth_weekday_of_month(
+                                -1 if number == "last" else int(number[0]),
+                                WEEKDAYS[weekday],
+                                MONTHS[month],
+                                self._year,
+                            ),
+                            +int(days) if delta_direction == "past" else -int(days),
+                        ),
                     )
-                    + timedelta(days=+int(days) if delta_direction == "past" else -int(days)),
-                )
 
             # Handle <nth> <weekday> <before/from> <month> <day> patterns (e.g.,
             # _add_holiday_1st_mon_before_jun_15() or _add_holiday_1st_mon_from_jun_15()).
-            nth_weekday_from = re.match(
-                r"_add_holiday_(\d{1,2})\w{2}_(\w+)_(before|from)_(\w{3})_(\d{1,2})", name
-            )
-            if nth_weekday_from:
-                number, weekday, date_direction, month, day = nth_weekday_from.groups()
-                return lambda name: self._add_holiday(
-                    name,
-                    _get_nth_weekday_from(
-                        -int(number) if date_direction == "before" else +int(number),
-                        getattr(gregorian, weekday.upper()),
-                        date(self._year, getattr(gregorian, month.upper()), int(day)),
-                    ),
-                )
+            elif len(tokens) == 8:
+                *_, number, weekday, date_direction, month, day = tokens
+                if (
+                    date_direction in {"before", "from"}
+                    and number[0].isdigit()
+                    and month in MONTHS
+                    and weekday in WEEKDAYS
+                    and day in DAYS
+                ):
+                    return lambda name: self._add_holiday(
+                        name,
+                        _get_nth_weekday_from(
+                            -int(number[0]) if date_direction == "before" else +int(number[0]),
+                            WEEKDAYS[weekday],
+                            date(self._year, MONTHS[month], int(day)),
+                        ),
+                    )
 
             raise e  # No match.
 
@@ -527,7 +584,7 @@ class HolidayBase(Dict[date, str]):
 
             days_in_range = []
             for delta_days in range(0, date_diff.days, step):
-                day = start + timedelta(days=delta_days)
+                day = _timedelta(start, delta_days)
                 if day in self:
                     days_in_range.append(day)
 
@@ -546,6 +603,7 @@ class HolidayBase(Dict[date, str]):
 
         to :class:`datetime.date`, which is how it's stored by the class."""
 
+        dt: Optional[date] = None
         # Try to catch `date` and `str` type keys first.
         # Using type() here to skip date subclasses.
         # Key is `date`.
@@ -554,10 +612,17 @@ class HolidayBase(Dict[date, str]):
 
         # Key is `str` instance.
         elif isinstance(key, str):
-            try:
-                dt = parse(key).date()
-            except (OverflowError, ValueError):
-                raise ValueError(f"Cannot parse date from string '{key}'")
+            # key possibly contains a date in YYYY-MM-DD or YYYYMMDD format.
+            if len(key) in {8, 10}:
+                try:
+                    dt = date.fromisoformat(key)
+                except ValueError:
+                    pass
+            if dt is None:
+                try:
+                    dt = parse(key).date()
+                except (OverflowError, ValueError):
+                    raise ValueError(f"Cannot parse date from string '{key}'")
 
         # Key is `datetime` instance.
         elif isinstance(key, datetime):
@@ -595,7 +660,7 @@ class HolidayBase(Dict[date, str]):
     def __radd__(self, other: Any) -> "HolidayBase":
         return self.__add__(other)
 
-    def __reduce__(self) -> Union[str, Tuple[Any, ...]]:
+    def __reduce__(self) -> Union[str, tuple[Any, ...]]:
         return super().__reduce__()
 
     def __repr__(self) -> str:
@@ -629,7 +694,7 @@ class HolidayBase(Dict[date, str]):
             # If there are multiple holidays on the same date
             # order their names alphabetically.
             holiday_names = set(self[key].split(HOLIDAY_NAME_DELIMITER))
-            holiday_names.add(value)
+            holiday_names.update(value.split(HOLIDAY_NAME_DELIMITER))
             value = HOLIDAY_NAME_DELIMITER.join(sorted(holiday_names))
 
         dict.__setitem__(self, self.__keytransform__(key), value)
@@ -647,15 +712,7 @@ class HolidayBase(Dict[date, str]):
 
     @property
     def __attribute_names(self):
-        return (
-            "country",
-            "expand",
-            "language",
-            "market",
-            "observed",
-            "subdiv",
-            "years",
-        )
+        return ("country", "expand", "language", "market", "observed", "subdiv", "years")
 
     @cached_property
     def _entity_code(self):
@@ -676,14 +733,18 @@ class HolidayBase(Dict[date, str]):
             .lower()
         )
 
-    @cached_property
+    @property
     def _sorted_categories(self):
-        return sorted(self.categories)
+        return (
+            [self.default_category] + sorted(self.categories - {self.default_category})
+            if self.default_category in self.categories
+            else sorted(self.categories)
+        )
 
     @classmethod
-    def get_subdivision_aliases(cls) -> Dict[str, List]:
+    def get_subdivision_aliases(cls) -> dict[str, list]:
         """Get subdivision aliases."""
-        subdivision_aliases: Dict[str, List[str]] = {s: [] for s in cls.subdivisions}
+        subdivision_aliases: dict[str, list[str]] = {s: [] for s in cls.subdivisions}
         for alias, subdivision in cls.subdivisions_aliases.items():
             subdivision_aliases[subdivision].append(alias)
 
@@ -724,14 +785,14 @@ class HolidayBase(Dict[date, str]):
                     )
                 else:  # Substituted holidays.
                     to_month, to_day, from_month, from_day, *optional = data
+                    from_date = date(optional[0] if optional else self._year, from_month, from_day)
                     self._add_holiday(
                         self.tr(self.substituted_label)
-                        % date(
-                            optional[0] if optional else self._year, from_month, from_day
-                        ).strftime(self.tr(self.substituted_date_format)),
+                        % from_date.strftime(self.tr(self.substituted_date_format)),
                         to_month,
                         to_day,
                     )
+                    self.weekend_workdays.add(from_date)
 
     def _check_weekday(self, weekday: int, *args) -> bool:
         """
@@ -789,6 +850,9 @@ class HolidayBase(Dict[date, str]):
         >>> us_holidays.update(country_holidays('US', years=2021))
         """
 
+        if year < self.start_year or year > self.end_year:
+            return None
+
         self._year = year
         self._populate_common_holidays()
         self._populate_subdiv_holidays()
@@ -823,7 +887,7 @@ class HolidayBase(Dict[date, str]):
                 for category in self._sorted_categories
             )
 
-    def append(self, *args: Union[Dict[DateLike, str], List[DateLike], DateLike]) -> None:
+    def append(self, *args: Union[dict[DateLike, str], list[DateLike], DateLike]) -> None:
         """Alias for :meth:`update` to mimic list type."""
         return self.update(*args)
 
@@ -852,7 +916,7 @@ class HolidayBase(Dict[date, str]):
         """
         return dict.get(self, self.__keytransform__(key), default)
 
-    def get_list(self, key: DateLike) -> List[str]:
+    def get_list(self, key: DateLike) -> list[str]:
         """Return a list of all holiday names for a date if date is a holiday,
         else empty string.
 
@@ -870,7 +934,7 @@ class HolidayBase(Dict[date, str]):
 
     def get_named(
         self, holiday_name: str, lookup="icontains", split_multiple_names=True
-    ) -> List[date]:
+    ) -> list[date]:
         """Return a list of all holiday dates matching the provided holiday
         name. The match will be made case insensitively and partial matches
         will be included by default.
@@ -922,6 +986,72 @@ class HolidayBase(Dict[date, str]):
 
         raise AttributeError(f"Unknown lookup type: {lookup}")
 
+    def get_closest_holiday(
+        self,
+        target_date: DateLike = None,
+        direction: Literal["forward", "backward"] = "forward",
+    ) -> Optional[tuple[date, str]]:
+        """Return the date and name of the next holiday for a target_date
+        if direction is "forward" or the previous holiday if direction is "backward".
+        If target_date is not provided the current date will be used by default."""
+
+        if direction not in {"backward", "forward"}:
+            raise AttributeError(f"Unknown direction: {direction}")
+
+        dt = self.__keytransform__(target_date or datetime.now().date())
+        if direction == "forward" and (next_year := dt.year + 1) not in self.years:
+            self._populate(next_year)
+        elif direction == "backward" and (previous_year := dt.year - 1) not in self.years:
+            self._populate(previous_year)
+
+        sorted_dates = sorted(self.keys())
+        position = (
+            bisect_right(sorted_dates, dt)
+            if direction == "forward"
+            else bisect_left(sorted_dates, dt) - 1
+        )
+        if 0 <= position < len(sorted_dates):
+            dt = sorted_dates[position]
+            return dt, self[dt]
+
+        return None
+
+    def get_nth_working_day(self, key: DateLike, n: int) -> date:
+        """Return n-th working day from provided date (if n is positive)
+        or n-th working day before provided date (if n is negative).
+        """
+        direction = +1 if n > 0 else -1
+        dt = self.__keytransform__(key)
+        for _ in range(abs(n)):
+            dt = _timedelta(dt, direction)
+            while not self.is_working_day(dt):
+                dt = _timedelta(dt, direction)
+        return dt
+
+    def get_working_days_count(self, start: DateLike, end: DateLike) -> int:
+        """Return the number of working days between two dates.
+
+        The date range works in a closed interval fashion [start, end] so both
+        endpoints are included.
+
+        :param start:
+            The range start date.
+
+        :param end:
+            The range end date.
+        """
+        dt1 = self.__keytransform__(start)
+        dt2 = self.__keytransform__(end)
+        if dt1 > dt2:
+            dt1, dt2 = dt2, dt1
+        days = (dt2 - dt1).days + 1
+        return sum(self.is_working_day(_timedelta(dt1, n)) for n in range(days))
+
+    def is_working_day(self, key: DateLike) -> bool:
+        """Return True if date is a working day (not a holiday or a weekend)."""
+        dt = self.__keytransform__(key)
+        return dt in self.weekend_workdays if self._is_weekend(dt) else dt not in self
+
     def pop(self, key: DateLike, default: Union[str, Any] = None) -> Union[str, Any]:
         """If date is a holiday, remove it and return its date, else return
         default.
@@ -950,7 +1080,7 @@ class HolidayBase(Dict[date, str]):
 
         return dict.pop(self, self.__keytransform__(key), default)
 
-    def pop_named(self, name: str) -> List[date]:
+    def pop_named(self, name: str) -> list[date]:
         """Remove (no longer treat at as holiday) all dates matching the
         provided holiday name. The match will be made case insensitively and
         partial matches will be removed.
@@ -958,9 +1088,6 @@ class HolidayBase(Dict[date, str]):
         :param name:
             The holiday's name to try to match.
 
-        :param default:
-            The default value to return if no match is found.
-
         :return:
             A list of dates removed.
 
@@ -968,8 +1095,7 @@ class HolidayBase(Dict[date, str]):
             KeyError if date is not a holiday and default is not given.
         """
         use_exact_name = HOLIDAY_NAME_DELIMITER in name
-        dts = self.get_named(name, split_multiple_names=not use_exact_name)
-        if len(dts) == 0:
+        if not (dts := self.get_named(name, split_multiple_names=not use_exact_name)):
             raise KeyError(name)
 
         popped = []
@@ -987,13 +1113,13 @@ class HolidayBase(Dict[date, str]):
                     if name_lower not in holiday_name.lower()
                 ]
 
-                if len(holiday_names) > 0:
+                if holiday_names:
                     self[dt] = HOLIDAY_NAME_DELIMITER.join(holiday_names)
 
         return popped
 
     def update(  # type: ignore[override]
-        self, *args: Union[Dict[DateLike, str], List[DateLike], DateLike]
+        self, *args: Union[dict[DateLike, str], list[DateLike], DateLike]
     ) -> None:
         # TODO: fix arguments; should not be *args (cannot properly Type hint)
         """Update the object, overwriting existing dates.
@@ -1033,15 +1159,15 @@ class HolidaySum(HolidayBase):
     are merged. All years are calculated (expanded) for all operands.
     """
 
-    country: Union[str, List[str]]  # type: ignore[assignment]
+    country: Union[str, list[str]]  # type: ignore[assignment]
     """Countries included in the addition."""
-    market: Union[str, List[str]]  # type: ignore[assignment]
+    market: Union[str, list[str]]  # type: ignore[assignment]
     """Markets included in the addition."""
-    subdiv: Optional[Union[str, List[str]]]  # type: ignore[assignment]
+    subdiv: Optional[Union[str, list[str]]]  # type: ignore[assignment]
     """Subdivisions included in the addition."""
-    holidays: List[HolidayBase]
+    holidays: list[HolidayBase]
     """The original HolidayBase objects included in the addition."""
-    years: Set[int]
+    years: set[int]
     """The years calculated."""
 
     def __init__(
@@ -1081,7 +1207,7 @@ country_holidays('CA') + country_holidays('MX')
             else:
                 self.holidays.append(operand)
 
-        kwargs: Dict[str, Any] = {}
+        kwargs: dict[str, Any] = {}
         # Join years, expand and observed.
         kwargs["years"] = h1.years | h2.years
         kwargs["expand"] = h1.expand or h2.expand
@@ -1124,4 +1250,4 @@ country_holidays('CA') + country_holidays('MX')
     def _populate(self, year):
         for operand in self.holidays:
             operand._populate(year)
-            self.update(cast("Dict[DateLike, str]", operand))
+            self.update(cast("dict[DateLike, str]", operand))
