@@ -7,17 +7,20 @@
 #  Authors: Vacanza Team and individual contributors (see AUTHORS file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
-#  Website: https://github.com/vacanza/python-holidays
+#  Website: https://github.com/vacanza/holidays
 #  License: MIT (see LICENSE file)
 
 import importlib
-from typing import Any, Dict, Iterable, Optional, Tuple, Union
+from collections.abc import Iterable
+from threading import RLock
+from typing import Any, Optional, Union
 
 from holidays.holiday_base import HolidayBase
 
-RegistryDict = Dict[str, Tuple[str, ...]]
+RegistryDict = dict[str, tuple[str, ...]]
 
 COUNTRIES: RegistryDict = {
+    "afghanistan": ("Afghanistan", "AF", "AFG"),
     "albania": ("Albania", "AL", "ALB"),
     "algeria": ("Algeria", "DZ", "DZA"),
     "american_samoa": ("AmericanSamoa", "AS", "ASM", "HolidaysAS"),
@@ -51,6 +54,7 @@ COUNTRIES: RegistryDict = {
     "chile": ("Chile", "CL", "CHL"),
     "china": ("China", "CN", "CHN"),
     "colombia": ("Colombia", "CO", "COL"),
+    "congo": ("Congo", "CG", "COG"),
     "costa_rica": ("CostaRica", "CR", "CRI"),
     "croatia": ("Croatia", "HR", "HRV"),
     "cuba": ("Cuba", "CU", "CUB"),
@@ -59,9 +63,11 @@ COUNTRIES: RegistryDict = {
     "czechia": ("Czechia", "CZ", "CZE"),
     "denmark": ("Denmark", "DK", "DNK"),
     "djibouti": ("Djibouti", "DJ", "DJI"),
+    "dominica": ("Dominica", "DM", "DMA"),
     "dominican_republic": ("DominicanRepublic", "DO", "DOM"),
     "ecuador": ("Ecuador", "EC", "ECU"),
     "egypt": ("Egypt", "EG", "EGY"),
+    "jordan": ("Jordan", "JO", "JOR"),
     "el_salvador": ("ElSalvador", "SV", "SLV"),
     "estonia": ("Estonia", "EE", "EST"),
     "eswatini": ("Eswatini", "SZ", "SZW", "Swaziland"),
@@ -73,8 +79,11 @@ COUNTRIES: RegistryDict = {
     "germany": ("Germany", "DE", "DEU"),
     "ghana": ("Ghana", "GH", "GHA"),
     "greece": ("Greece", "GR", "GRC"),
+    "greenland": ("Greenland", "GL", "GRL"),
     "guam": ("Guam", "GU", "GUM", "HolidaysGU"),
     "guatemala": ("Guatemala", "GT", "GUA"),
+    "guernsey": ("Guernsey", "GG", "GGY"),
+    "haiti": ("Haiti", "HT", "HTI"),
     "honduras": ("Honduras", "HN", "HND"),
     "hongkong": ("HongKong", "HK", "HKG"),
     "hungary": ("Hungary", "HU", "HUN"),
@@ -105,6 +114,7 @@ COUNTRIES: RegistryDict = {
     "maldives": ("Maldives", "MV", "MDV"),
     "malta": ("Malta", "MT", "MLT"),
     "marshall_islands": ("MarshallIslands", "MH", "MHL", "HolidaysMH"),
+    "mauritania": ("Mauritania", "MR", "MRT"),
     "mexico": ("Mexico", "MX", "MEX"),
     "moldova": ("Moldova", "MD", "MDA"),
     "monaco": ("Monaco", "MC", "MCO"),
@@ -120,6 +130,7 @@ COUNTRIES: RegistryDict = {
     "northern_mariana_islands": ("NorthernMarianaIslands", "MP", "MNP", "HolidaysMP"),
     "norway": ("Norway", "NO", "NOR"),
     "pakistan": ("Pakistan", "PK", "PAK"),
+    "palau": ("Palau", "PW", "PLW"),
     "panama": ("Panama", "PA", "PAN"),
     "papua_new_guinea": ("PapuaNewGuinea", "PG", "PNG"),
     "paraguay": ("Paraguay", "PY", "PRY"),
@@ -130,6 +141,9 @@ COUNTRIES: RegistryDict = {
     "puerto_rico": ("PuertoRico", "PR", "PRI", "HolidaysPR"),
     "romania": ("Romania", "RO", "ROU"),
     "russia": ("Russia", "RU", "RUS"),
+    "saint_kitts_and_nevis": ("SaintKittsAndNevis", "KN", "KNA"),
+    "saint_lucia": ("SaintLucia", "LC", "LCA"),
+    "samoa": ("Samoa", "WS", "WSM"),
     "san_marino": ("SanMarino", "SM", "SMR"),
     "saudi_arabia": ("SaudiArabia", "SA", "SAU"),
     "serbia": ("Serbia", "RS", "SRB"),
@@ -140,6 +154,7 @@ COUNTRIES: RegistryDict = {
     "south_africa": ("SouthAfrica", "ZA", "ZAF"),
     "south_korea": ("SouthKorea", "KR", "KOR", "Korea"),
     "spain": ("Spain", "ES", "ESP"),
+    "sri_lanka": ("SriLanka", "LK", "LKA"),
     "sweden": ("Sweden", "SE", "SWE"),
     "switzerland": ("Switzerland", "CH", "CHE"),
     "taiwan": ("Taiwan", "TW", "TWN"),
@@ -149,6 +164,7 @@ COUNTRIES: RegistryDict = {
     "tonga": ("Tonga", "TO", "TON"),
     "tunisia": ("Tunisia", "TN", "TUN"),
     "turkey": ("Turkey", "TR", "TUR"),
+    "tuvalu": ("Tuvalu", "TV", "TUV"),
     "ukraine": ("Ukraine", "UA", "UKR"),
     "united_arab_emirates": ("UnitedArabEmirates", "AE", "ARE"),
     "united_kingdom": ("UnitedKingdom", "GB", "GBR", "UK"),
@@ -171,10 +187,17 @@ COUNTRIES: RegistryDict = {
 }
 
 FINANCIAL: RegistryDict = {
-    "european_central_bank": ("EuropeanCentralBank", "ECB", "TAR"),
-    "ny_stock_exchange": ("NewYorkStockExchange", "NYSE", "XNYS"),
+    "european_central_bank": ("EuropeanCentralBank", "XECB", "ECB", "TAR"),
+    "ice_futures_europe": ("ICEFuturesEurope", "IFEU"),
+    "ny_stock_exchange": ("NewYorkStockExchange", "XNYS", "NYSE"),
+    "brasil_bolsa_balcao": ("BrasilBolsaBalcao", "BVMF", "B3"),
 }
 
+# A re-entrant lock. Once a thread has acquired a re-entrant lock,
+# the same thread may acquire it again without blocking.
+# https://docs.python.org/3/library/threading.html#rlock-objects
+IMPORT_LOCK = RLock()
+
 
 class EntityLoader:
     """Country and financial holidays entities lazy loader."""
@@ -185,7 +208,7 @@ class EntityLoader:
         """Set up a lazy loader."""
         if args:
             raise TypeError(
-                "This is a python-holidays entity loader class. "
+                "This is a holidays entity loader class. "
                 "For entity inheritance purposes please import a class you "
                 "want to derive from directly: e.g., "
                 "`from holidays.countries import Entity` or "
@@ -220,7 +243,10 @@ class EntityLoader:
     def get_entity(self) -> Optional[HolidayBase]:
         """Return lazy-loaded entity."""
         if self.entity is None:
-            self.entity = getattr(importlib.import_module(self.module_name), self.entity_name)
+            # Avoid deadlock due to importlib.import_module not being thread-safe by caching all
+            # the first imports in a dedicated thread.
+            with IMPORT_LOCK:
+                self.entity = getattr(importlib.import_module(self.module_name), self.entity_name)
 
         return self.entity
 
@@ -258,7 +284,7 @@ class EntityLoader:
         return EntityLoader._get_entity_codes(FINANCIAL, (3, 4), include_aliases)
 
     @staticmethod
-    def load(prefix: str, scope: Dict) -> None:
+    def load(prefix: str, scope: dict) -> None:
         """Load country or financial entities."""
         entity_mapping = COUNTRIES if prefix == "countries" else FINANCIAL
         for module, entities in entity_mapping.items():
